<a href="https://github.com/KennethEnevoldsen/snp-transformer"><img src="https://github.com/KennethEnevoldsen/snp-transformer/blob/main/docs/_static/icon.png?raw=true" width="300" align="right"/></a>

# SNP Transformer

[![PyPI](https://img.shields.io/pypi/v/snp-transformer.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/snp-transformer)][pypi status]
[![Tests](https://github.com/KennethEnevoldsen/snp-transformer/actions/workflows/tests.yml/badge.svg)][tests]
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi status]: https://pypi.org/project/snp-transformer/
[documentation]: https://KennethEnevoldsen.github.io/snp-transformer/
[tests]: https://github.com/KennethEnevoldsen/snp-transformer/actions?workflow=Tests
[black]: https://github.com/psf/black


<!-- start short-description -->

Transformer encoders for genetic SNPs

<!-- end short-description -->

## Installation

You can install `snp-transformer` via [pip] from [PyPI]:

```bash
pip install snp-transformer
```

[pip]: https://pip.pypa.io/en/stable/installing/
[PyPI]: https://pypi.org/project/snp-transformer/

## Usage

TODO: Add minimal usage example

To see more examples, see the [documentation].



# 💬 Where to ask questions

| Type                           |                        |
| ------------------------------ | ---------------------- |
| 🚨 **Bug Reports**              | [GitHub Issue Tracker] |
| 🎁 **Feature Requests & Ideas** | [GitHub Issue Tracker] |
| 👩‍💻 **Usage Questions**          | [GitHub Discussions]   |
| 🗯 **General Discussion**       | [GitHub Discussions]   |

[Documentation]: https://KennethEnevoldsen.github.io/snp-transformer/index.html
[Installation]: https://KennethEnevoldsen.github.io/snp-transformer/installation.html
[Tutorials]: https://KennethEnevoldsen.github.io/snp-transformer/tutorials.html
[API Reference]: https://KennethEnevoldsen.github.io/snp-transformer/references.html
[FAQ]: https://KennethEnevoldsen.github.io/snp-transformer/faq.html
[github issue tracker]: https://github.com/KennethEnevoldsen/snp-transformer/issues
[github discussions]: https://github.com/KennethEnevoldsen/snp-transformer/discussions


